import { dataSource } from "../../data-source";
import { memberQualifications } from "../../entity/club/member/memberQualifications";
import { qualification } from "../../entity/settings/qualification";
import { user } from "../../entity/user/user";
import InternalException from "../../exceptions/internalException";

export default abstract class QualificationService {
  /**
   * @description get all qualifications
   * @returns {Promise<Array<qualification>>}
   */
  static async getAll(): Promise<Array<qualification>> {
    return await dataSource
      .getRepository(qualification)
      .createQueryBuilder("qualification")
      .orderBy("qualification", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("qualifications not found", err);
      });
  }

  /**
   * @description get qualification by id
   * @returns {Promise<qualification>}
   */
  static async getById(id: number): Promise<qualification> {
    return await dataSource
      .getRepository(qualification)
      .createQueryBuilder("qualification")
      .where("qualification.id = :id", { id: id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("qualification not found by id", err);
      });
  }
}
